==> haskell-libyaml-0.1.2-228-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libyaml
version:              0.1.2
visibility:           public
id:                   libyaml-0.1.2-8Ix0zATS0R4IIwVCVTbPru
key:                  libyaml-0.1.2-8Ix0zATS0R4IIwVCVTbPru
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:             Text
abi:                  7a113447a001d46984a0c1f8bf914ace
exposed:              True
exposed-modules:      Text.Libyaml
hidden-modules:       Paths_libyaml
import-dirs:          /usr/lib/ghc-9.0.2/site-local/libyaml-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/libyaml-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libyaml
hs-libraries:         HSlibyaml-0.1.2-8Ix0zATS0R4IIwVCVTbPru
extra-libraries:      yaml
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    conduit-1.3.4.2-3ize03GpnWc9m0IW4KzDCT
    resourcet-1.2.5-57cDD5gh8ZkIiqQoFkkzIL

haddock-interfaces:   /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:         /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.2-232-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libyaml
version:              0.1.2
visibility:           public
id:                   libyaml-0.1.2-2keTNDTD7tDGJ8BVo6aFsL
key:                  libyaml-0.1.2-2keTNDTD7tDGJ8BVo6aFsL
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:             Text
abi:                  371b7b857dac29f65ec98379d18f1c12
exposed:              True
exposed-modules:      Text.Libyaml
hidden-modules:       Paths_libyaml
import-dirs:          /usr/lib/ghc-9.0.2/site-local/libyaml-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/libyaml-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libyaml
hs-libraries:         HSlibyaml-0.1.2-2keTNDTD7tDGJ8BVo6aFsL
extra-libraries:      yaml
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    conduit-1.3.4.2-5Sfb9MxGjGeJfVZ4wYaBEO
    resourcet-1.2.6-7SxpuU6eh4f7w9cLMDUzC1

haddock-interfaces:   /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:         /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
